@@ -25,53 +25,79 @@
 #                                                                            #
 ##############################################################################
 
+use strict;
+
 package FAQ::OMatic::appearanceForm;
 
 use CGI;
 use FAQ::OMatic;
+use FAQ::OMatic::I18N;
+use FAQ::OMatic::HelpMod;
 
 sub main {
-	my $cgi = $FAQ::OMatic::dispatch::cgi;
+	my $cgi = FAQ::OMatic::dispatch::cgi();
 	
 	my $params = FAQ::OMatic::getParams($cgi);
 
 	my $page = '';
 
-	$page.=FAQ::OMatic::pageHeader();
+	$page.=FAQ::OMatic::pageHeader($params, ['help', 'faq']);
 	
-	$page.="<h3>Appearance Options</h3>";
+	$page.="<h3>".gettext("Appearance Options")."</h3>";
+
+# Data structure key:
+#		['parameterName',			# as resolved by $params->{'parameterName'}
+#			['value-names', ...],	# one per table column
+#			['value', ...],			# as will appear in value="" field
+#			'description'],			# text description of parameter
 
 	my $boxes = [
 #		['recurse',
-#			['', 'Show', 'Hide'],
+#			['', gettext("Show"), gettext("Hide")],
 #			['', '1', ''],
-#			'all categories and answers below current category'],
+#			gettext("all categories and answers below current category")],
+		['editCmds',
+			[gettext("Show"), gettext("Compact"), gettext("Hide")],
+			['show', 'compact', 'hide'],
+			gettext("expert editing commands")],
 		['showModerator',
-			['', 'Show', 'Hide'],
-			['', '1', ''],
-			'name of moderator who organizes current category'],
+			['', gettext("Show"), gettext("Hide")],
+			['', 'show', 'hide'],
+			gettext("name of moderator who organizes current category")],
 		['showLastModified',
-			['', 'Show', 'Hide'],
-			['', '1', ''],
-			'last modified date'],
-		['showEditCmds',
-			['', 'Show', 'Hide'],
-			['', '1', ''],
-			'editing commands'],
+			['', gettext("Show"), gettext("Hide")],
+			['', 'show', 'hide'],
+			gettext("last modified date")],
+# showLastModifiedAlways is now obsolete; that default will be handled
+# in the (new) standard way using OMatic::getParam().
+#		($FAQ::OMatic::Config::showLastModifiedAlways||0)
+#			? ['',
+#				['', '', ''],
+#				['', '', ''],
+#				'<i>last modified date always shown</i>']
+#			: ['showLastModified',
+#				['', 'Show', 'Hide'],
+#				['', '1', ''],
+#				'last modified date']
+#			,
 		['showAttributions',
-			['Show All', 'Default', 'Hide'],
-			['all', '', 'hide'],
-			'attributions'],
-		['simple',
-			['', 'Simple', 'Fancy'],
-			['', '1', ''],
-			'HTML']
+			[gettext("Show"), gettext("Default"), gettext("Hide")],
+			['all', 'default', 'hide'],
+			gettext("attributions")],
+		['render',
+			['', gettext("Simple"), gettext("Fancy")],
+			['', 'simple', 'tables'],
+			'HTML'],
+		['textCmds',
+			['', gettext("Show"), gettext("Hide")],
+			['', 'show', 'hide'],
+			gettext("commands for generating text output")]
 	];
 
 	$page.=FAQ::OMatic::makeAref("faq",
 			# kill all params that have a form entry
 			{ map {$_->[0] => ''} @{$boxes} },
-			'POST')
+			'GET')
 		."<table>\n";
 	my ($setup, $choice);
 	foreach $setup (@{$boxes}) {
@@ -84,7 +110,7 @@ sub main {
 					."\" value=\""
 					.$setup->[2][$choice]
 					."\"";
-				my $existing = $params->{$setup->[0]} || '';
+				my $existing = FAQ::OMatic::getParam($params, $setup->[0]);
 				if ($existing eq $setup->[2][$choice]) {
 					$page.=" checked\n";
 				}
@@ -97,11 +123,11 @@ sub main {
 		$page.="</tr>";
 	}
 	$page.="<tr><td></td><td></td><td></td><td align=left>"
-		."<input type=submit name=\"_fromAppearance\" value=\"Accept\">"
+		."<input type=submit name=\"_fromAppearance\" value=\"".gettext("Accept")."\">"
 		."</td></tr>\n";
 	$page.="</table></form>\n";
 
-	$page.=FAQ::OMatic::Help::helpFor($params, 'Appearance Options', "\n");
+	$page.=FAQ::OMatic::HelpMod::helpFor($params, 'Appearance Options', "\n");
 
 	$page.= FAQ::OMatic::pageFooter($params, ['help', 'faq']);
 
