@@ -25,22 +25,28 @@
 #                                                                            #
 ##############################################################################
 
+use strict;
+
 package FAQ::OMatic::editPart;
 
 use CGI;
 use FAQ::OMatic::Item;
 use FAQ::OMatic;
 use FAQ::OMatic::Auth;
+use FAQ::OMatic::I18N;
+use FAQ::OMatic::HelpMod;
 
 sub main {
-	my $cgi = $FAQ::OMatic::dispatch::cgi;
+	my $cgi = FAQ::OMatic::dispatch::cgi();
 	my $rt='';
 
 	my $params = FAQ::OMatic::getParams($cgi);
 
-	$rt .= FAQ::OMatic::pageHeader($params);
+	FAQ::OMatic::mirrorsCantEdit($cgi, $params);
+
+	$rt .= FAQ::OMatic::pageHeader($params, ['help', 'faq']);
 	
-	$item = new FAQ::OMatic::Item($params->{'file'});
+	my $item = new FAQ::OMatic::Item($params->{'file'});
 	if ($item->isBroken()) {
 		FAQ::OMatic::gripe('error', "The file (".$params->{'file'}
 			.") doesn't exist.");
@@ -53,6 +59,17 @@ sub main {
 	my $insertpart = $params->{'_insertpart'};
 
 	my $partnum = $params->{'partnum'};
+	if ($partnum =~ m/afterLast/) {
+		# it's possible to come from a mirror, who might be enough
+		# out of date that naming a specific part number would cause
+		# the [Append to This Answer] link to sometimes cause people to
+		# unintentionally insert text before existing text.
+		# The pattern match lets us send something like '9999afterLast',
+		# which will cause older versions (which a newer mirror may
+		# point to) to generate a nice error message, instead of
+		# letting the user edit the wrong part.
+		$partnum = scalar(@{$item->{'Parts'}}) - 1;
+	}
 	my $part = undef;
 	if ($partnum >= 0) {
 		$part = $item->getPart($partnum);
@@ -98,49 +115,69 @@ sub main {
 	if ($part->{'Text'} =~ m/^\s*$/s) {
 		# if the part starts out empty, we're as good as adding, not
 		# editing existing content.
-		my $rd = FAQ::OMatic::Auth::ensurePerm($item, 'PermAddPart',
-			FAQ::OMatic::commandName(), $cgi, 0);
-		if ($rd) { print $rd; exit 0; }
+		# We let the item author add any new parts he wants.
+		FAQ::OMatic::Auth::ensurePerm('-item'=>$item,
+			'-operation'=>'PermAddPart',
+			'-restart'=>FAQ::OMatic::commandName(),
+			'-cgi'=>$cgi,
+			'-failexit'=>1);
 	} else {
-		my $rd = FAQ::OMatic::Auth::ensurePerm($item, 'PermEditPart',
-			FAQ::OMatic::commandName(), $cgi, 0);
-		if ($rd) { print $rd; exit 0; }
+		FAQ::OMatic::Auth::ensurePerm('-item'=>$item,
+			'-operation'=>'PermEditPart',
+			'-restart'=>FAQ::OMatic::commandName(),
+			'-cgi'=>$cgi,
+			'-failexit'=>1);
+
+		if ($part->{'Type'} eq 'html') {
+			# discourage unauthorized users from editing HTML parts which
+			# they won't later be able to submit.
+			FAQ::OMatic::Auth::ensurePerm('-item'=>$item,
+				'-operation'=>'PermUseHTML',
+				'-restart'=>FAQ::OMatic::commandName(),
+				'-cgi'=>$cgi,
+				'-xreason'=>'useHTML',
+				'-failexit'=>1);
+		}
 	}
 	
 	if ($params->{'_insertpart'}) {
 		my $insertHint = $params->{'_insert'} || '';
 		if ($insertHint eq 'answer') {
-			$rt .= "Enter the answer to <b>".$item->getTitle()."</b>\n";
+			$rt .= gettexta("Enter the answer to <b>%0</b>", $item->getTitle())."\n";
 		} elsif ($insertHint eq 'category') {
-			$rt .= "Enter a description for <b>".$item->getTitle()."</b>\n";
+			$rt .= gettexta("Enter a description for <b>%0</b>", $item->getTitle())."\n";
 		} elsif ($params->{'_duplicate'}) {
-			$rt .= "Edit duplicated text for <b>".$item->getTitle()."</b>\n";
+			$rt .= gettexta("Edit duplicated text for <b>%0</b>", $item->getTitle())."\n";
 		} else {
-			$rt .= "Enter new text for <b>".$item->getTitle()."</b>\n";
+			$rt .= gettexta("Enter new text for <b>%0</b>", $item->getTitle())."\n";
 		}
 	} else {
 		# little white lie -- user sees 1-based indices, but parts
 		# are stored 0-based. Is this bad?
-		$rt .= "Editing the ".cardinal($partnum+1)." text part in <b>"
-			.$item->getTitle()."</b>\n";
+		$rt .= gettexta("Editing the %0 text part in <b>%1</b>.", 
+				FAQ::OMatic::cardinal($partnum+1), $item->getTitle())
+			."\n";
 	}
 	$rt .= $part->displayPartEditor($item, $partnum, $params);
 
-	$rt .= FAQ::OMatic::Help::helpFor($params, 'editPart', "<br>\n");
-	$rt .= FAQ::OMatic::Help::helpFor($params, 'makingLinks', "<br>\n");
-	$rt .= FAQ::OMatic::Help::helpFor($params, 'seeAlso', "<br>\n");
+	$rt .= FAQ::OMatic::HelpMod::helpFor($params, 'editPart', "<br>\n");
+	$rt .= FAQ::OMatic::HelpMod::helpFor($params, 'makingLinks', "<br>\n");
+	$rt .= FAQ::OMatic::HelpMod::helpFor($params, 'seeAlso', "<br>\n");
+
+	# TODO: this will probably be unnecessary once there is a help system.
+	if (FAQ::OMatic::getParam($params, 'editCmds') eq 'hide') {
+		$rt .=
+		    "<p>" .
+		    gettexta("If you later need to edit or delete this text, use the [Appearance] page to turn on the expert editing commands.") .
+		    "\n";
+	}
 
 	$rt .= FAQ::OMatic::pageFooter($params, ['help','faq']);
 
 	print $rt;
 }
 
-sub cardinal {
-	my $num = shift;
-	my %numsuffix=('0'=>'th', '1'=>'st', '2'=>'nd', '3'=>'rd', '4'=>'th',
-				   '5'=>'th', '6'=>'th', '7'=>'th', '8'=>'th', '9'=>'th');
-	my $suffix = ($num>=11 and $num<=19) ? 'th' : $numsuffix{substr($num,-1,1)};
-	return $num."<sup>".$suffix."</sup>";
-}
-
 1;
+
+
+
